# Credits

Bull S. A. S.

## Development Lead

 * Pierre FUMERY (Atos) <pierre.fumery@atos.net>
 * Yves VINTER (Atos) <yves.vinter@atos.net>
 * Francois WAESELYNCK (Atos) <francois.waeselynck@atos.net>
 * Elisabet BIALUNGANA LOUREIRO (Atos) <elisabet.bialunganaloureiro@atos.net>
 * Nabil MAMORI (Atos) <nabil.mamori@atos.net>
 * Grégory NATTER (Atos) <gregory.natter@atos.net>

## Contributors

None yet.

## Thanks to

 * Jérémie Lallemand
